$AssetsModelsGen class

Constructors

$AssetsModelsGen()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mobilenetLivenessV3 String
File path: assets/models/mobilenet_liveness_v3.tflite
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of all assets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited