AppStrings class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- approve → const String
- assetDetail → const String
- cancelRequest → const String
- createLeaveRequest → const String
- detailLeaveRequest → const String
- enterReasonForLeave → const String
- enterReasonForReject → const String
- from → const String
- fromDate → const String
- leaveRequest → const String
- login → const String
- notificationAll → const String
- notificationRead → const String
- notificationUnRead → const String
- passwordRequired → const String
- personalApprove → const String
- personalEvaluator → const String
- practicalWork → const String
- reasonForCancel → const String
- reasonForLeave → const String
- reasonForReject → const String
- reject → const String
- selectApprove → const String
- selectDateTimeEnd → const String
- selectDateTimeStart → const String
- selectTime → const String
- selectTypeLeave → const String
- standardMeasure → const String
- status → const String
- timeOff → const String
- titleNotification → const String
- to → const String
- toDate → const String
- typeLeave → const String
- wrongPassword → const String