TextStyles class

Constructors

TextStyles()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bodyText → const TextStyle
caption → const TextStyle
caption2 → const TextStyle
heading1 → const TextStyle
heading2 → const TextStyle
text14 → const TextStyle
title → const TextStyle
title2 → const TextStyle