StatusFace enum
Values
- notRegister → const StatusFace
-
const StatusFace('not_register', 'Nhân viên chưa đăng ký') - notRecognize → const StatusFace
-
const StatusFace('not_recognize', 'Không nhận ra khuôn mặt') - success → const StatusFace
-
const StatusFace('success', 'Nhận diện thành công') - notAllow → const StatusFace
-
const StatusFace('not_allow', 'Bạn đang không đứng trong phạm vi chấm công')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- key → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromKey(
String key) → StatusFace?
Constants
-
values
→ const List<
StatusFace> - A constant List of the values in this enum, in order of their declaration.